summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/index_bounds_builder.h
diff options
context:
space:
mode:
authorJudah Schvimer <judah@mongodb.com>2016-09-15 10:20:59 -0400
committerJudah Schvimer <judah@mongodb.com>2016-09-15 10:20:59 -0400
commit4dc41d135737dbda0a9ecc70af75687dd5df9099 (patch)
tree381dcdf024db4da65d20051a430a4f7515c122d6 /src/mongo/db/query/index_bounds_builder.h
parent97dd4a8eebfb2a2dc2e3a5e0907c8fc6e859c0ac (diff)
downloadmongo-4dc41d135737dbda0a9ecc70af75687dd5df9099.tar.gz
SERVER-26033 Allow simple range to exclude start key
Diffstat (limited to 'src/mongo/db/query/index_bounds_builder.h')
-rw-r--r--src/mongo/db/query/index_bounds_builder.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/mongo/db/query/index_bounds_builder.h b/src/mongo/db/query/index_bounds_builder.h
index 5d3c02e029f..b397f81b295 100644
--- a/src/mongo/db/query/index_bounds_builder.h
+++ b/src/mongo/db/query/index_bounds_builder.h
@@ -108,15 +108,14 @@ public:
* Make a range interval from the provided object.
* The object must have exactly two fields. The first field is the start, the second the
* end.
* The two inclusive flags indicate whether or not the start/end fields are included in the
* interval (closed interval if included, open if not).
*/
- static Interval makeRangeInterval(const BSONObj& obj, bool startInclusive, bool endInclusive);
+ static Interval makeRangeInterval(const BSONObj& obj, BoundInclusion boundInclusion);
static Interval makeRangeInterval(const std::string& start,
const std::string& end,
- bool startInclusive,
- bool endInclusive);
+ BoundInclusion boundInclusion);
/**
* Make a point interval from the provided object.
@@ -108,15 +108,14 @@ public:
* The object must have exactly two fields. The first field is the start, the second the
* end.
- * The two inclusive flags indicate whether or not the start/end fields are included in the
+ * The BoundInclusion indicates whether or not the start/end fields are included in the
* interval (closed interval if included, open if not).
*/